(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     64279,       1563]*)
(*NotebookOutlinePosition[     65364,       1597]*)
(*  CellTagsIndexPosition[     65320,       1593]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["(*  This cell makes Mathematica \"smart\" and \"friendly\"  *)\n\
(*  It won't hurt anything to leave it out  *)",
    FontColor->RGBColor[0, 0, 1]],
  "\n$HistoryLength=6;\nClear[\"Global`*\"];\n\
Off[General::spell1,General::spell]"
}], "Input",
  PageWidth->Infinity,
  ShowSpecialCharacters->False],

Cell["\<\
red = RGBColor[1,0,0];
green = RGBColor[0,1,0];
blue = RGBColor[0,0,1];
yellow =  RGBColor[1,0.9,0];
brown =  RGBColor[0.5,0.5,0];
magenta = RGBColor[0.8,0,0.2];
(*SetDirectory[\"CS\"];*)\
\>", "Input",
  PageWidth->Infinity,
  ShowSpecialCharacters->False],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["(*  Equilibrium lattice constants  *)",
    FontColor->RGBColor[0, 0, 1]],
  "\nbaeq = 7.653394;\naaeq = 6.657508;\n\n",
  StyleBox["(*  LAPW data for A  *)",
    FontColor->RGBColor[0, 0, 1]],
  "\navolE={\n {   6.657508    ,  0.0000000E+00},\n {   6.803017    ,   \
24.92476    },\n {   6.991990    ,   118.5069    },\n {   7.180962    ,   \
260.8557    },\n {   7.369935    ,   434.8278    },\n {   7.558908    ,   \
628.1257    },\n {   7.653394    ,   729.7726    }\n };\n\n",
  StyleBox["(* Fit the hydrostatic energy of A.  *)",
    FontColor->RGBColor[1, 0, 0]],
  "\navol = Fit[ avolE, {(x-aaeq)^2, (x-aaeq)^3, (x-aaeq)^4, (x-aaeq)^5}, x];\
\n\n",
  StyleBox["(*  LAPW data for B   *)",
    FontColor->RGBColor[0, 0, 1]],
  "\nbvolE={\n {   6.657508    ,   3124.012    },\n {   6.803017    ,   \
2075.526    },\n {   6.991990    ,   1120.430    },\n {   7.180962    ,   \
516.7408    },\n {   7.369935    ,   173.6507    },\n {   7.558908    ,   \
21.47341    },\n {   7.653394    ,  0.0000000E+00}\n };\n\n",
  StyleBox["(* Fit the hydrostatic energy of B.  *)",
    FontColor->RGBColor[1, 0, 0]],
  "\nbvol = Fit[ bvolE, {(x-baeq)^2, (x-baeq)^3, (x-baeq)^4, (x-baeq)^5}, x];\
\n\n",
  StyleBox["(* Plot the volume fits *)",
    FontColor->RGBColor[1, 0, 0]],
  "\nPlot[ {avol,bvol}, {x,6.6,7.7}, Frame->True, \
PlotRange->{-50,3200},PlotStyle -> {red, green}, AspectRatio -> 0.85,\n\t\
DefaultFont -> {\"Helvetica\", 22},Epilog->{PointSize[0.015], red, Point /@ \
avolE,green, Point /@ bvolE},\n\tFrameLabel->{\"Lattice Constant\", \
\"Energy\"} ]\n"
}], "Input",
  PageWidth->Infinity,
  ShowSpecialCharacters->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["(*  LAPW data for A.  *)",
    FontColor->RGBColor[0, 0, 1]],
  "\nadata100=\n {\n {   6.657508    ,  0.0000000E+00},\n {   6.803017    ,   \
2.218246    },\n {   6.991990    ,   20.02192    },\n {   7.180962    ,   \
37.12273    },\n {   7.369935    ,   43.96582    },\n {   7.558908    ,   \
50.63963    },\n {   7.653394    ,   50.81177    }\n };\n adata110=\n {\n {   \
6.657508    ,  0.0000000E+00},\n {   6.803017    ,   8.626938    },\n {   \
6.991990    ,   48.09093    },\n {   7.180962    ,   115.3755    },\n {   \
7.369935    ,   202.4007    },\n {   7.558908    ,   303.2617    },\n {   \
7.653394    ,   358.9897    }\n };\n adata111=\n {\n {   6.657508    ,  \
0.0000000E+00},\n {   6.803017    ,   7.100582    },\n {   6.991990    ,   \
40.74097    },\n {   7.180962    ,   95.02267    },\n {   7.369935    ,   \
160.0156    },\n {   7.558908    ,   228.1675    },\n {   7.653394    ,   \
265.7609    }\n };\n adata201=\n {\n {   6.657508    ,  0.0000000E+00},\n {   \
6.803017    ,   5.625725    },\n {   6.991990    ,   19.83213    },\n {   \
7.180962    ,   84.67149    },\n {   7.369935    ,   190.4774    },\n {   \
7.558908    ,   259.1677    },\n {   7.653394    ,   306.9487    }\n };\n \
adata311=\n {\n {   6.657508    ,  0.0000000E+00},\n {   6.803017    ,   \
2.862930    },\n {   6.991990    ,   31.53467    },\n {   7.180962    ,   \
73.80486    },\n {   7.369935    ,   133.1687    },\n {   7.558908    ,   \
197.9785    },\n {   7.653394    ,   229.9576    }\n };\n",
  StyleBox["(*  Fit the lattice parameter dependence of epitaxial energies.  \
*)",
    FontColor->RGBColor[1, 0, 0]],
  "\n\n(*    ------  a -------     *)\na311 = Fit[adata311, \
{(aaeq-x)^2,(aaeq-x)^3}, x];\na201 = Fit[adata201, \
{(aaeq-x)^2,(aaeq-x)^3,(aaeq-x)^4}, x];\na110 = Fit[adata110, \
{(aaeq-x)^2,(aaeq-x)^3,(aaeq-x)^4,(aaeq-x)^5}, x];\na111 = Fit[adata111, \
{(aaeq-x)^2,(aaeq-x)^3,(aaeq-x)^4,(aaeq-x)^5}, x];\na100 = Fit[adata100, \
{(aaeq-x)^2,(aaeq-x)^3,(aaeq-x)^4,(aaeq-x)^5}, x];\n\naq311 = a311 / avol;\n\
aq201 = a201 / avol;\naq110 = a110 / avol;\naq111 = a111 / avol;\naq100 = \
a100 / avol;\n\n\n",
  StyleBox["(*  LAPW data for B *)",
    FontColor->RGBColor[0, 0, 1]],
  "\nbdata100=\n {\n {   6.657508    ,   590.0178    },\n {   6.803017    ,   \
364.2573    },\n {   6.991990    ,   175.1342    },\n {   7.180962    ,   \
66.75768    },\n {   7.369935    ,   18.85605    },\n {   7.558908    ,   \
1.314640    },\n {   7.653394    ,  0.0000000E+00}\n };\n bdata110=\n {\n {   \
6.657508    ,   265.5239    },\n {   6.803017    ,   166.9092    },\n {   \
6.991990    ,   85.13879    },\n {   7.180962    ,   44.85369    },\n {   \
7.369935    ,   24.87898    },\n {   7.558908    ,   7.853985    },\n {   \
7.653394    ,  0.0000000E+00}\n };\n bdata111=\n {\n {   6.657508    ,   \
867.5909    },\n {   6.803017    ,   543.3278    },\n {   6.991990    ,   \
270.7977    },\n {   7.180962    ,   128.1290    },\n {   7.369935    ,   \
67.12294    },\n {   7.558908    ,   10.95200    },\n {   7.653394    ,  \
0.0000000E+00}\n };\n bdata201=\n {\n {   6.657508    ,   146.7590    },\n {  \
 6.803017    ,   114.6426    },\n {   6.991990    ,   77.64673    },\n {   \
7.180962    ,   45.88079    },\n {   7.369935    ,   28.07093    },\n {   \
7.558908    ,   6.108761    },\n {   7.653394    ,  0.0000000E+00}\n };\n \
bdata311=\n {\n {   6.657508    ,   407.8717    },\n {   6.803017    ,   \
267.1409    },\n {   6.991990    ,   155.2300    },\n {   7.180962    ,   \
85.60371    },\n {   7.369935    ,   40.31467    },\n {   7.558908    ,   \
6.423950    },\n {   7.653394    ,  0.0000000E+00}\n };\n\nb311 = \
Fit[bdata311, {(baeq-x)^2,(baeq-x)^3,(baeq-x)^4,(baeq-x)^5}, x];\nb201 = \
Fit[bdata201, {(baeq-x)^2,(baeq-x)^3,(baeq-x)^4,(baeq-x)^5}, x];\nb110 = \
Fit[bdata110, {(baeq-x)^2,(baeq-x)^3,(baeq-x)^4,(baeq-x)^5}, x];\nb111 = \
Fit[bdata111, {(baeq-x)^2,(baeq-x)^3,(baeq-x)^4,(baeq-x)^5}, x];\nb100 = \
Fit[bdata100, {(baeq-x)^2,(baeq-x)^3,(baeq-x)^4,(baeq-x)^5}, x];\n\nbq311 = \
b311 / bvol;\nbq201 = b201 / bvol;\nbq110 = b110 / bvol;\nbq111 = b111 / \
bvol;\nbq100 = b100 / bvol;\n\n",
  StyleBox["(*   Plot the fits.   *)",
    FontColor->RGBColor[1, 0, 0]],
  "\np311=Plot[ {a311, b311}, {x,6.6,7.7}, Frame->True, \
PlotRange->{-20,600},PlotStyle -> {red, green}, FrameLabel->{\"Lattice \
constant\",\"Energy\",\"311\",\"\"},DisplayFunction->Identity,AspectRatio -> \
0.85,DefaultFont -> {\"Helvetica\",14},Epilog->{PointSize[0.015], red, Point \
/@ adata311,green, Point /@ bdata311} ];\np201=Plot[ {a201, b201}, \
{x,6.6,7.7}, Frame->True,PlotRange->{-20,600}, PlotStyle -> {red, green}, \
FrameLabel->{\"Lattice constant\",\"Energy\",\"201\",\"\"},AspectRatio -> \
0.85,\tDefaultFont -> {\"Helvetica\", 14}, \
DisplayFunction->Identity,Epilog->{PointSize[0.015], red, Point /@ adata201, \
green, Point /@ bdata201} ];\np110=Plot[ {a110, b110}, {x,6.6,7.7}, \
PlotRange->{-20,600}, Frame->True,PlotStyle -> {red, \
green},FrameLabel->{\"Lattice constant\",\"Energy\",\"110\",\"\"}, \
AspectRatio -> 0.85,DefaultFont -> {\"Helvetica\", 14}, \
DisplayFunction->Identity,Epilog->{PointSize[0.015], red, Point /@ \
adata110,green, Point /@ bdata110} ];\np111=Plot[ {a111, b111}, {x,6.6,7.7}, \
PlotRange->{-20,600}, Frame->True,PlotStyle -> {red, green}, \
FrameLabel->{\"Lattice constant\",\"Energy\",\"111\",\"\"},AspectRatio -> \
0.85,DefaultFont -> {\"Helvetica\", \
14},DisplayFunction->Identity,Epilog->{PointSize[0.015], red, Point /@ \
adata111,\tgreen,Point /@ bdata111} ];\np100=Plot[ {a100, b100}, {x,6.6,7.7}, \
Frame->True,PlotRange->{-20,600},PlotStyle -> {red, \
green},FrameLabel->{\"Lattice constant\",\"Energy\",\"100\",\"\"}, \
DisplayFunction->Identity,AspectRatio -> 0.85,DefaultFont -> {\"Helvetica\", \
14},Epilog->{PointSize[0.015], red, Point /@ adata100,green, Point /@ \
bdata100} ];\nepigraphs=GraphicsArray[{{p100,p110,p111},{p201,p311}}]\n\
Show[epigraphs]\n \
Export[\"ExpitaxialStrainInputs.eps\",epigraphs,ImageSize->1200]; "
}], "Input",
  PageWidth->Infinity,
  ShowSpecialCharacters->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["(*     Define the \"weighted average\" strain.   *)",
    FontColor->RGBColor[1, 0, 0]],
  "\n GofX[c_,x_] = (1-c) avol + c bvol; \n\ncs100[c_,x_] = (1-c) a100 + c \
b100;\ncs111[c_,x_] = (1-c) a111 + c b111;\ncs110[c_,x_] = (1-c) a110 + c \
b110;\ncs201[c_,x_] = (1-c) a201 + c b201;\ncs311[c_,x_] = (1-c) a311 + c \
b311;\nview={3.106, -1.044, 0.845};\n\
g1=Plot3D[cs100[c,x],{c,0,1},{x,aaeq,baeq},DisplayFunction->Identity,\
ViewPoint->view,PlotLabel->\"100\",BoxRatios->{1,1,1}];\n\
g2=Plot3D[cs110[c,x],{c,0,1},{x,aaeq,baeq},DisplayFunction->Identity,\
ViewPoint->view,PlotLabel->\"110\",BoxRatios->{1,1,1}];\n\
g3=Plot3D[cs111[c,x],{c,0,1},{x,aaeq,baeq},DisplayFunction->Identity,\
ViewPoint->view,PlotLabel->\"111\",BoxRatios->{1,1,1}];\n\
g4=Plot3D[cs201[c,x],{c,0,1},{x,aaeq,baeq},DisplayFunction->Identity,\
ViewPoint->view,PlotLabel->\"201\",BoxRatios->{1,1,1}];\n\
g5=Plot3D[cs311[c,x],{c,0,1},{x,aaeq,baeq},DisplayFunction->Identity,\
ViewPoint->view,PlotLabel->\"311\",BoxRatios->{1,1,1}];\n\
weightedaverageplots=GraphicsArray[{{g1,g2,g3},{g4,g5}},DisplayFunction->$\
DisplayFunction];\nShow[weightedaverageplots]\n\
Export[\"WeightedAverage.eps\",weightedaverageplots,ImageSize->1200];"
}], "Input",
  PageWidth->Infinity,
  ShowSpecialCharacters->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["(* Calculate the coherency strain *)",
    FontColor->RGBColor[1, 0, 0]],
  "\ncseq100 = Table[ FindMinimum[cs100[i*0.025,x], {x,aaeq,baeq}], \
{i,0,40}]; ",
  StyleBox["(* 100 *)",
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  "\ncseq111 = Table[ FindMinimum[cs111[i*0.025,x], {x,aaeq,baeq}], \
{i,0,40}]; ",
  StyleBox["(* 111 *)",
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  "\ncseq110 = Table[ FindMinimum[cs110[i*0.025,x], {x,aaeq,baeq}], \
{i,0,40}]; ",
  StyleBox["(* 110 *)\n",
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  "cseq201 = Table[ FindMinimum[cs201[i*0.025,x], {x,aaeq,baeq}], {i,0,40}]; \
",
  StyleBox["(* 201 *)",
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  "\ncseq311 = Table[ FindMinimum[cs311[i*0.025,x], {x,aaeq,baeq}], \
{i,0,40}]; ",
  StyleBox["(* 311 *)",
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  "\n\n",
  StyleBox["(*   Interpolate and plot the coherency strain   *)",
    FontColor->RGBColor[1, 0, 0]],
  "\nconcentrations = Table[i*0.025, {i,0,40}];\n\nGofXeq = Table[ \
FindMinimum[GofX[i*0.025,x], {x,aaeq,baeq}], {i,0,40}];\nGofXeq = \
Transpose[GofXeq];\nevol = Transpose[{concentrations, GofXeq[[1]]} ];\n\
alatvol = Transpose[{concentrations, x /. GofXeq[[2]]} ];\n\nGofXfun = \
Interpolation[evol, InterpolationOrder->1];\nalatfunvol = \
Interpolation[alatvol,  InterpolationOrder->1];\n\ncseq100 = \
Transpose[cseq100];",
  StyleBox["(* 100 *)",
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  "\ne100 = Transpose[{concentrations, cseq100[[1]]} ];\nalat100 = \
Transpose[{concentrations, x /. cseq100[[2]]} ];\necsfun100 = \
Interpolation[e100, InterpolationOrder->1];\nalatfun100 = \
Interpolation[alat100,  InterpolationOrder->1];\n\ncseq111 = \
Transpose[cseq111];",
  StyleBox["(* 111 *)",
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  "\ne111 = Transpose[{concentrations, cseq111[[1]]} ];\nalat111 = \
Transpose[{concentrations, x /. cseq111[[2]]} ];\necsfun111 = \
Interpolation[e111, InterpolationOrder->2];\nalatfun111 = \
Interpolation[alat111,  InterpolationOrder->2];\n\ncseq110 = \
Transpose[cseq110];",
  StyleBox["(* 110 *)",
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  "\ne110 = Transpose[{concentrations, cseq110[[1]]} ];\nalat110 = \
Transpose[{concentrations, x /. cseq110[[2]]} ];\necsfun110 = \
Interpolation[e110, InterpolationOrder->2];\nalatfun110 = \
Interpolation[alat110,  InterpolationOrder->2];\n\ncseq201 = \
Transpose[cseq201];",
  StyleBox["(* 201 *)",
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  "\ne201 = Transpose[{concentrations, cseq201[[1]]} ];\nalat201 = \
Transpose[{concentrations, x /. cseq201[[2]]} ];\necsfun201 = \
Interpolation[e201, InterpolationOrder->2];\nalatfun201 = \
Interpolation[alat201,  InterpolationOrder->2];\n\ncseq311 = \
Transpose[cseq311];",
  StyleBox["(* 311 *)",
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  "\ne311 = Transpose[{concentrations, cseq311[[1]]} ];\nalat311 = \
Transpose[{concentrations, x /. cseq311[[2]]} ];\necsfun311 = \
Interpolation[e311, InterpolationOrder->2];\nalatfun311 = \
Interpolation[alat311,  InterpolationOrder->2];\n"
}], "Input",
  PageWidth->Infinity,
  ShowSpecialCharacters->False],

Cell[CellGroupData[{

Cell["\<\
GofXplot = Plot[ {GofXfun[c]}, {c,0,1},PlotRange->All, \
Frame->True,AspectRatio -> 0.85, DefaultFont -> {\"Helvetica\", \
18},FrameLabel -> {\"Concentration\", \"Energy, meV/atom\",\"G(x)\", \
\"\"},DisplayFunction->Identity];
aGofXplot = Plot[ {alatfunvol[c]}, {c,0,1},PlotRange->All, \
Frame->True,AspectRatio -> 0.85, DefaultFont -> {\"Helvetica\", \
18},FrameLabel -> {\"Concentration\", \"Lattice parameter\",\"Lattice par. \
for G(x)\", \"\"},DisplayFunction->Identity];
gofxplots=GraphicsArray[{GofXplot,aGofXplot},DisplayFunction->$\
DisplayFunction]
Show[gofxplots]
Export[\"GofXplot.eps\",gofxplots,ImageSize->1200];\
\>", "Input",
  PageWidth->Infinity,
  ShowSpecialCharacters->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ecsplot = Plot[ {ecsfun100[c], ecsfun111[c], ecsfun110[c],ecsfun201[c], \
ecsfun311[c]}, {c,0,1},PlotRange->{{0,1},{-10,120}}, Frame->True,PlotStyle -> \
{red,green,blue,yellow,brown}, 
\tAspectRatio -> 0.85, DefaultFont -> {\"Helvetica\", 22},FrameLabel -> {\"[] \
Concentration\", \"Energy, meV/atom\",\"Constituent strain \", \
\"\"},Epilog->{red,Text[\"100\", {0.9,40}],
\tgreen,  Text[\"111\", {0.9,35}],blue,   Text[\"110\", {0.9,30}],yellow, \
Text[\"201\", {0.9,25}],brown,  Text[\"311\", {0.9,20}] \
},DisplayFunction->Identity];
alatplot = Plot[ {alatfun100[c], alatfun111[c], alatfun110[c], \t\
alatfun201[c],alatfun311[c]}, {c,0,1},PlotRange->{6.6,7.7}, Frame->True, \
AxesOrigin -> {0,0},PlotStyle -> {red,green,blue,yellow,brown}, 
\tAspectRatio -> 0.85, DefaultFont -> {\"Helvetica\", 22},FrameLabel -> {\"[] \
Concentration\", \"Lattice parameter, a.u.\",\"Lattice parameter of A/B \
superlattices\", \"\"},
\tEpilog->{red,    Text[\"100\", {0.9,4.35}],
\t\t\t green,  Text[\"111\", {0.9,4.32}],
\t\t\t blue,   Text[\"110\", {0.9,4.29}],
\t\t\t yellow, Text[\"201\", {0.9,4.26}],
\t\t\t brown,  Text[\"311\", {0.9,4.23}] },DisplayFunction->Identity];
ecsplots=GraphicsArray[{ecsplot,alatplot},DisplayFunction->$DisplayFunction]
Show[ecsplots]
Export[\"ConstituentStrain.eps\",ecsplots,ImageSize->1200];
\
\>", "Input",
  PageWidth->Infinity,
  ShowSpecialCharacters->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "(*    Define Kubic harmonics.   *)\nr2 = k^2 + l^2 + m^2;\n\nK0 = \
Sqrt[1/(4 Pi)];\nK4 = Sqrt[1/(4 Pi)] Sqrt[21/4] (1 - 5 (k^2 l^2 + k^2 m^2 + \
l^2 m^2) / r2^2);\nK6 = Sqrt[1/(4 Pi)] Sqrt[13/2] (1/4) (7 (k^6+l^6+m^6+30 \
k^2 l^2 m^2)/r2^3 - 5);\nK8 = Sqrt[1/(4 Pi)] Sqrt[561] (1/8) (k^8 + l^8 + m^8 \
- \n\t14 (k^6 l^2 + k^6 m^2 +\tl^6 m^2 + k^2 l^6 + k^2 m^6 + l^2 m^6) + \n\t\
35 (k^4 l^4 + k^4 m^4 + l^4 m^4)) / r2^4;\n\nxx = Sin[theta] Cos[phi];\nyy = \
Sin[theta] Sin[phi];\nzz = Cos[theta];\n\n(*   Fit the angular dependence of \
the constituent strain energy.\n     Edit the list of spherical harmonics to \
be used in the fit.  \n     *)\nfuntab = {K0, K4, K6, K8}; (* Table of the \
first 4 non-zero terms in a Kubic harmonic expansion (for cubic symmetry)  *)\
\ncctab = {a0, a4, a6, a8};\n\n(* Do not change this part *)\nenergies = \
Transpose[ {Transpose[e100][[2]], Transpose[e110][[2]],Transpose[e111][[2]], \
Transpose[e201][[2]], Transpose[e311][[2]] }];\ndirections = {{1,0,0}, \
{1,1,0}, {1,1,1}, {2,0,1}, {3,1,1}}; ",
  StyleBox["(*   MAKE SURE THESE ARE IN THE SAME ORDER AS IN \"energies\"  \
*)",
    FontColor->RGBColor[1, 0, 0],
    FontVariations->{"Underline"->True}],
  "\ncoefftab = {};\nerrortab = {};\nrmstab = {};\nrelerrtab = {};\nic =.;\n\
conctab = Table[i*0.025, {i,1,Length[energies]-2}];"
}], "Input",
  PageWidth->Infinity,
  ShowSpecialCharacters->False],

Cell[CellGroupData[{

Cell["\<\
Do[ klmtab = FlattenAt[ Transpose[{directions, energies[[ic]]} ], \
Table[{i,1}, {i,Length[energies[[ic]]]}] ];
\tklmfit = Fit[ klmtab, funtab, {k,l,m}];
\tfitform = cctab . funtab;
\tequations = Table[ ( fitform == klmfit ) /. \
{k->directions[[i]][[1]],l->directions[[i]][[2]], m->directions[[i]][[3]] \
},{i,Length[funtab]} ];
\tcoeffs = cctab /. Solve[ equations, cctab][[1]];
\terrors = energies[[ic]] - Table[ N[ klmfit /. \
{k->directions[[i]][[1]],l->directions[[i]][[2]], m->directions[[i]][[3]] } \
],{i,Length[directions]} ];
\trmsdev = Sqrt[ errors . errors / (Length[errors]-1)];
\trelerr = errors / energies[[ic]];
\tcoefftab = Append[coefftab, coeffs];
\terrortab = Append[ errortab, errors];
\trmstab = Append[ rmstab, rmsdev];
\trelerrtab = Append[ relerrtab, relerr];
\tPrint[ic,\" done\"],
{ic,2,Length[energies]-1} ];

\
\>", "Input",
  PageWidth->Infinity,
  ShowSpecialCharacters->False],

Cell[BoxData[
    InterpretationBox[\(2\[InvisibleSpace]" done"\),
      SequenceForm[ 2, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(3\[InvisibleSpace]" done"\),
      SequenceForm[ 3, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(4\[InvisibleSpace]" done"\),
      SequenceForm[ 4, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(5\[InvisibleSpace]" done"\),
      SequenceForm[ 5, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(6\[InvisibleSpace]" done"\),
      SequenceForm[ 6, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(7\[InvisibleSpace]" done"\),
      SequenceForm[ 7, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(8\[InvisibleSpace]" done"\),
      SequenceForm[ 8, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(9\[InvisibleSpace]" done"\),
      SequenceForm[ 9, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(10\[InvisibleSpace]" done"\),
      SequenceForm[ 10, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(11\[InvisibleSpace]" done"\),
      SequenceForm[ 11, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(12\[InvisibleSpace]" done"\),
      SequenceForm[ 12, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(13\[InvisibleSpace]" done"\),
      SequenceForm[ 13, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(14\[InvisibleSpace]" done"\),
      SequenceForm[ 14, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(15\[InvisibleSpace]" done"\),
      SequenceForm[ 15, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(16\[InvisibleSpace]" done"\),
      SequenceForm[ 16, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(17\[InvisibleSpace]" done"\),
      SequenceForm[ 17, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(18\[InvisibleSpace]" done"\),
      SequenceForm[ 18, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(19\[InvisibleSpace]" done"\),
      SequenceForm[ 19, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(20\[InvisibleSpace]" done"\),
      SequenceForm[ 20, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(21\[InvisibleSpace]" done"\),
      SequenceForm[ 21, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(22\[InvisibleSpace]" done"\),
      SequenceForm[ 22, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(23\[InvisibleSpace]" done"\),
      SequenceForm[ 23, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(24\[InvisibleSpace]" done"\),
      SequenceForm[ 24, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(25\[InvisibleSpace]" done"\),
      SequenceForm[ 25, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(26\[InvisibleSpace]" done"\),
      SequenceForm[ 26, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(27\[InvisibleSpace]" done"\),
      SequenceForm[ 27, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(28\[InvisibleSpace]" done"\),
      SequenceForm[ 28, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(29\[InvisibleSpace]" done"\),
      SequenceForm[ 29, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(30\[InvisibleSpace]" done"\),
      SequenceForm[ 30, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(31\[InvisibleSpace]" done"\),
      SequenceForm[ 31, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(32\[InvisibleSpace]" done"\),
      SequenceForm[ 32, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(33\[InvisibleSpace]" done"\),
      SequenceForm[ 33, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(34\[InvisibleSpace]" done"\),
      SequenceForm[ 34, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(35\[InvisibleSpace]" done"\),
      SequenceForm[ 35, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(36\[InvisibleSpace]" done"\),
      SequenceForm[ 36, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(37\[InvisibleSpace]" done"\),
      SequenceForm[ 37, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(38\[InvisibleSpace]" done"\),
      SequenceForm[ 38, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(39\[InvisibleSpace]" done"\),
      SequenceForm[ 39, " done"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(40\[InvisibleSpace]" done"\),
      SequenceForm[ 40, " done"],
      Editable->False]], "Print"]
}, Open  ]],

Cell["\<\
data = Table[ Table[ {conctab[[i]], coefftab[[i]][[j]]}, 
\t{i,Length[conctab]} ], {j,Length[coefftab[[1]]]} ];

datafun = Table[ Interpolation[ data[[i]], InterpolationOrder->2][x],
\t {i,Length[data]} ];
\
\>", "Input",
  PageWidth->Infinity,
  ShowSpecialCharacters->False],

Cell[TextData[{
  StyleBox["(*   Calculate and plot the errors of the fit, if you care.  *)",
    FontColor->RGBColor[1, 0, 0]],
  "\nerr100 = Transpose[errortab][[1]];\nerr110 = Transpose[errortab][[2]];\n\
err111 = Transpose[errortab][[3]];\nerr201 = Transpose[errortab][[4]];\n\
err311 = Transpose[errortab][[5]];\n\nerr100 = Transpose[{conctab, err100}];\n\
err110 = Transpose[{conctab, err111}];\nerr111 = Transpose[{conctab, \
err110}];\nerr201 = Transpose[{conctab, err201}];\nerr311 = \
Transpose[{conctab, err311}];\n\nerr100fun = Interpolation[ err100, \
InterpolationOrder -> 2 ];\nerr111fun = Interpolation[ err111, \
InterpolationOrder -> 2 ];\nerr110fun = Interpolation[ err110, \
InterpolationOrder -> 2 ];\nerr201fun = Interpolation[ err201, \
InterpolationOrder -> 2 ];\nerr311fun = Interpolation[ err311, \
InterpolationOrder -> 2 ];"
}], "Input",
  PageWidth->Infinity,
  ShowSpecialCharacters->False],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["(*   Plot the errors.  *)",
    FontColor->RGBColor[1, 0, 0]],
  "\nerrplot = Plot[ {err100fun[c], err111fun[c], err110fun[c], err201fun[c], \
err311fun[c]}, {c,.025,1-0.025}, PlotRange->{{0,1},{-20,25}}, Frame->True,\t\
PlotStyle -> {red,green,blue,yellow,brown}, \n\tAspectRatio -> 0.85, \
DefaultFont -> {\"Helvetica\", 22},FrameLabel -> {\"Concentration\", \
\"Energy, meV/atom\",\"Errors in the eq. strain energy\", \"\"},\n\t\
DisplayFunction->Identity,Epilog->{ red,    Text[\"<100>\", {0.85,15}],\n\t\t\
\t green,  Text[\"<111>\", {0.85,12.5}],\n\t\t\t blue,   Text[\"<110>\", \
{0.85,10}],\n\t\t\t yellow, Text[\"<201>\", {0.85,7.5}],\n\t\t\t brown,  \
Text[\"<311>\", {0.85,5}] }];\n\n",
  StyleBox["(*  Plot the expansion coefficients of the constituent  strain.  \
*)",
    FontColor->RGBColor[1, 0, 0]],
  "\nqplot = Plot[ Evaluate[datafun], {x,First[conctab],Last[conctab]}, \
Frame->True,\tPlotRange->{{0, 1},{-75,275}},AxesOrigin -> {aaeq, 0}, \
DefaultFont->{\"Helvetica\",22},\n\tPlotStyle -> {red,green,blue,yellow}, \
AspectRatio -> 0.85,FrameLabel -> {\"Concentration\", \
\"meV/atom\",\"Expansion coefficients of equilibrium Ecs\", \"\"},\n\t\
DisplayFunction->Identity, Epilog->{red, Text[\"A0\", {0.85,50}],\n\t\t\t \
green,  Text[\"A4\", {0.85,40}],\n\t\t\t blue,   Text[\"A6\", {0.85,30}],\n\t\
\t\t yellow, Text[\"A8\", {0.85,20}] }];\n\
Show[GraphicsArray[{errplot,qplot},DisplayFunction->$DisplayFunction]]\n\
Export[\"CSfiterror.eps\",%,ImageSize->1200];"
}], "Input",
  PageWidth->Infinity,
  ShowSpecialCharacters->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
allecsfun[x_, k_, l_, m_] = Evaluate[datafun] . funtab;

JCScoeffs = Table[ {conctab[[i]], coefftab[[i]] / 4 / conctab[[i]] /
\t (1-conctab[[i]])}, {i,Length[conctab]} ];

xx = Sin[theta] Cos[phi];
yy = Sin[theta] Sin[phi];
zz = Cos[theta];\
\>", "Input",
  PageWidth->Infinity,
  ShowSpecialCharacters->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["(*  Do some cool plots of the CS at different compositions.  *)\n\
",
    FontColor->RGBColor[1, 0, 0]],
  "concentration = 0.15;\nECSplot1 = ParametricPlot3D[ \
Evaluate[allecsfun[concentration, xx, yy, zz] {xx,yy,zz}], {phi, 0, 2 Pi}, \
{theta, 0.01, Pi-0.01},Axes -> False, Ticks -> None,BoxStyle -> \
{Thickness[.01]},\n\tDefaultFont->{\"Helvetica\",18}, PlotPoints -> {60,60}, \
PlotLabel -> None, DisplayFunction->Identity];\nECSplot2 = ParametricPlot3D[ \
Evaluate[allecsfun[concentration, xx, yy, zz] {xx,yy,zz}],\t{phi, 0, 2 Pi}, \
{theta, 0.01, Pi-0.01},\nDisplayFunction->Identity,\tAxes -> False, Ticks -> \
None,BoxStyle -> {Thickness[.01]},DefaultFont->{\"Helvetica\",18}, PlotPoints \
-> {60,60}, PlotLabel -> None,ViewPoint->{0.616, -3.313, 0.312} ];\n\
Show[GraphicsArray[{ECSplot1,ECSplot2},DisplayFunction->$DisplayFunction]]\n\
Export[\"3DCSplot.eps\",%,ImageSize->1200];\n(* ECSplotsbw =  \
ParametricPlot3D[ Evaluate[ allecsfun[concentration, xx, yy, zz] {xx,yy,zz}], \
{phi, 0, 2 Pi}, {theta, 0.01, Pi-0.01},\n\tAxes -> False, Ticks -> \
None,ColorOutput->GrayLevel,DefaultFont->{\"Helvetica\",18}, PlotPoints -> \
{40,40}, PlotLabel -> None ];*)"
}], "Input",
  PageWidth->Infinity,
  ShowSpecialCharacters->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(concentration = 0.85;\)\), "\n", 
    \(\(ECSplot3 = 
        ParametricPlot3D[
          Evaluate[allecsfun[concentration, xx, yy, zz]\ {xx, yy, zz}], {phi, 
            0, 2\ Pi}, {theta, 0.01, Pi - 0.01}, Axes \[Rule] False, 
          Ticks \[Rule] None, BoxStyle \[Rule] {Thickness[ .01]}, 
          DefaultFont \[Rule] {"\<Helvetica\>", 18}, 
          PlotPoints \[Rule] {60, 60}, PlotLabel \[Rule] None, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(concentration = 0.85;\)\), "\[IndentingNewLine]", 
    \(\(ECSplot4 = 
        ParametricPlot3D[
          Evaluate[allecsfun[concentration, xx, yy, zz]\ {xx, yy, zz}], {phi, 
            0, 2\ Pi}, {theta, 0.01, Pi - 0.01}, 
          DisplayFunction \[Rule] Identity, Axes \[Rule] False, 
          Ticks \[Rule] None, BoxStyle \[Rule] {Thickness[ .01]}, 
          DefaultFont \[Rule] {"\<Helvetica\>", 18}, 
          PlotPoints \[Rule] {60, 60}, 
          ViewPoint \[Rule] {0.616, \(-3.313\), 0.312}, 
          PlotLabel \[Rule] None];\)\), "\n", 
    \(Show[
      GraphicsArray[{ECSplot3, ECSplot4}, 
        DisplayFunction \[Rule] $DisplayFunction]]\), "\n", 
    \(\(Export["\<3DCSplot.eps\>", %, ImageSize \[Rule] 1200];\)\)}], "Input"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

ordcs = {1/9, 1/8, 1/4, 1/3, 1/2, 2/3, 3/4, 7/8, 8/9};
ecstab = Table[ N[allecsfun[ ordcs[[i]], directions[[j]][[1]], 
\t\tdirections[[j]][[2]], directions[[j]][[3]] ]], 
\t{i,Length[ordcs]}, {j,Length[directions]} ]

jcstab = Table[ N[allecsfun[ ordcs[[i]], directions[[j]][[1]], 
\t\tdirections[[j]][[2]], directions[[j]][[3]] ]] 
\t\t/ (4*ordcs[[i]]*(1-ordcs[[i]])), 
\t{i,Length[ordcs]}, {j,Length[directions]} ]



sofk = {{\"L10\", 1/2, {{1,0,0}, 1}}, 
\t{\"beta1\", 1/3, {(2/3) {1,0,0}, 8/9}},
\t{\"beta2\", 2/3, {(2/3) {1,0,0}, 8/9}},
\t{\"Z1\", 1/4, {(1/2) {1,0,0}, 1/2}, {{1,0,0}, 1/4} },
\t{\"Z2\", 1/2, {(1/2) {1,0,0}, 1}},
\t{\"Z3\", 3/4, {(1/2) {1,0,0}, 1/2}, {{1,0,0}, 1/4} },
\t{\"L11\", 1/2, {(1/2) {1,1,1}, 1} },
\t{\"alpha1\", 1/3, {(1/3) {1,1,1}, 8/9} },
\t{\"alpha2\", 2/3, {(1/3) {1,1,1}, 8/9} },
\t{\"V1\", 1/4, {(1/4) {1,1,1}, 1/2}, {(1/2) {1,1,1}, 1/4} },
\t{\"V2\", 1/2, {(1/4) {1,1,1}, 1} },
\t{\"V3\", 3/4, {(1/4) {1,1,1}, 1/2}, {(1/2) {1,1,1}, 1/4} },
\t{\"gamma1\", 1/3, {(2/3) {1,1,0}, 8/9} },
\t{\"gamma2\", 2/3, {(2/3) {1,1,0}, 8/9} },
\t{\"Y1\", 1/4, {(1/2) {1,1,0}, 1/2}, {{1,0,0}, 1/4} },
\t{\"Y2\", 1/2, {(1/2) {1,1,0}, 1} },
\t{\"Y3\", 3/4, {(1/2) {1,1,0}, 1/2}, {{1,0,0}, 1/4} },
\t{\"F1\", 1/4, {(1/2) {2,0,1}, 1/2}, { {1,0,0}, 1/4} },
\t{\"CH\", 1/2, {(1/2) {2,0,1}, 1} },
\t{\"F3\", 3/4, {(1/2) {2,0,1}, 1/2}, { {1,0,0}, 1/4} },
\t{\"W1\", 1/4, {(1/4) {3,1,1}, 1/2}, {(1/2) {1,1,1}, 1/4} },
\t{\"W2\", 1/2, {(1/4) {3,1,1}, 1} },
\t{\"W3\", 3/4, {(1/4) {3,1,1}, 1/2}, {(1/2) {1,1,1}, 1/4} },
\t{\"L1\", 1/4, {{1,0,0}, 3/4} },
\t{\"L3\", 3/4, {{1,0,0}, 3/4} },
\t{\"D1\", 1/8, {(1/2) {1,1,1}, 4/16}, {{1,0,0}, 3/16}},
\t{\"D7\", 7/8, {(1/2) {1,1,1}, 4/16}, {{1,0,0}, 3/16}},
\t{\"Ni8Nb_a\", 1/9, {(2/3) {1,1,0}, 16/81}, {(2/3) {1,0,0}, 16/81} },
\t{\"Ni8Nb_b\", 8/9, {(2/3) {1,1,0}, 16/81}, {(2/3) {1,0,0}, 16/81} },
\t{\"SQS14a\", 1/4, {(1/4) {0,-1,2}, 2*0.21338835}, 
\t\t\t{(1/2) {2,1,0}, 2*0.12500000},
\t\t\t{(1/4) {0,3,2}, 2*0.03661165} },
\t{\"SQS14b\", 3/4, {(1/4) {0,-1,2}, 2*0.21338835}, 
\t\t\t{(1/2) {2,1,0}, 2*0.12500000},
\t\t\t{(1/4) {0,3,2}, 2*0.03661165} },
\t{\"DO23a\", 1/4, {{1,0,0}, 1/4}, {(1/4) {0,4,1}, 1/2}},
\t{\"DO23b\", 3/4, {{1,0,0}, 1/4}, {(1/4) {0,4,1}, 1/2}},
\t{\"Z8\", 7/8, {(1/4){1,0,0}, 1/8}, {(1/2){1,0,0}, 1/8},
\t        {(3/4){1,0,0}, 1/8}, {{1,0,0}, 1/16}},
\t{\"Z8.2\", 3/4, {(1/4){1,0,0}, 2*0.21338835}, {(1/2){1,0,0}, 1/4},
\t        {(3/4){1,0,0}, 2*0.03661165}},
\t{\"LPS-21a\", 1/4, {{1,0,0}, 11/36}, {(1/3){3,1,0}, 4/9}},
\t{\"LPS-3a\", 1/4, {{1,0,0}, 1/4}, 
\t\t\t{(1/2) {2,0,1}, 1/18}, 
\t\t\t{(1/6) {6,1,0}, 4/9} },
\t{\"Z16\", 15/16, {(1/8){1,0,0}, 1/32}, {(1/4){1,0,0}, 1/32},
\t        {(3/8){1,0,0}, 1/32}, {(1/2){1,0,0}, 1/32},
\t        {(5/8){1,0,0}, 1/32}, {(3/4){1,0,0}, 1/32},
\t        {(7/8){1,0,0}, 1/32}, {{1,0,0}, 1/64}},
\t{\"Z16.2\", 7/8, {(1/8){1,0,0}, 2*0.0601212336}, 
\t        {(1/4){1,0,0}, 2*0.05334708914},
\t        {(3/8){1,0,0}, 2*0.04320885487}, 
\t        {(1/2){1,0,0}, 1/16},
\t        {(5/8){1,0,0}, 2*0.01929114146}, 
\t        {(3/4){1,0,0}, 2*0.00915291293},
\t        {(7/8){1,0,0}, 2*0.00237876453}}, 
\t{\"D16\", 15/16, {{1,0,0}, 3/64}, {(1/2){1,1,0}, 12/64}},
\t{\"Z3.r5xr5\", 11/15, {(2/3){1,0,0}, 128/225}, {(1/5){3,1,1}, 8/225},
\t        {(1/5){3,3,1}, 8/225},
\t        {(1/15){9,3,7}, 8/225}, {(1/15){6,12,2}, 8/225},
\t        {(1/15){6,12,4}, 8/225}, {(1/15){3,9,1}, 8/225}},
\t{\"Z3.r2xr2\", 7/8, {{1,0,0}, 3/16}, 
\t        {(1/2){1,0,0}, 2/16},
\t        {(1/2){2,1,0}, 2/16}},
\t{\"P110_125a\" , 1/8, {{0,1,0},1/16},{(1/2){-1,0,1},1/8}},
\t{\"CXY_125a\", 1/8, \
{(1/2){1,0,1},1/8},{{0,1,0},1/16},{(1/2){-1,1,1},1/8},{(1/2){2,1,0},1/8}},
\t{\"BMONO_3x1\", 1/6, \
{(2/3){0,1,0},2/9},{(1/6){3,-1,3},2/9},{(1/2){1,1,1},1/9}},
\t{\"SMONOA\",1/6,{(2/3){-1,1,0},2/9},{(1/2){1,1,1},1/9},{(1/6){5,1,-3},2/9}},\

\t{\"P111_3x1\",1/6,{(1/3){1,-1,-1},2/9},{(1/3){1,-1,2},2/9},{{0,0,1},1/9}},
\t{\"P110_25\",1/4,{(1/2){-1,0,1},1/4},{{0,1/2,0},1/4},{(1/2){1,1,-1},1/4}},
\t{\"CXY_25a\",1/4,{{0,1,0},1/4},{(1/2){-1,1,1},1/2}},
\t{\"CXY_25b\",1/4,{(1/2){1,0,1},1/4},{{0,1/2,1},1/4},{(1/2){1,1,-1},1/4}},
\t{\"BMONO_B\",1/3,{{0,2/3,0},2/9},{(1/6){3,-1,3},2/9},{(1/2){1,1,1},4/9}},
\t{\"SMONO_B\",1/3,{(2/3){-1,1,0},2/9},{(1/2){1,1,1},4/9},{(1/6){5,1,-3},2/9}}\
,
\t{\"TEST79\",1/3,{(2/3){1,0,1},2/9},{(1/6){5,3,-1},2/3}},
\t{\"Sc2S3\",1/3,{(1/6){3,-2,4},2/3},{(2/3){0,1,1},2/9}},
\t{\"D4\",1/2,{(1/2){1,1,-1},3/4},{(1/2){1,1,1},1/4}}
};




(* Old form of the constituent strain energy. Nonattenuated  *)
straintable = Table[ {sofk[[i,1]], 
\tN[ Sum[ (1/(4 sofk[[i,2]] ( 1-sofk[[i,2]] ) )) *
\t\tsofk[[i,j,2]] * allecsfun[ sofk[[i,2]], sofk[[i,j,1,1]], 
\t\t\tsofk[[i,j,1,2]], sofk[[i,j,1,3]] ], 
\t{j,3,Length[sofk[[i]]] } ] ]}, 
{i,Length[sofk]} ]

(* \"Attenuated\" constituent strain energy.  *)
sigma = 999999;
straintable = Table[ {sofk[[i,1]],
\tN[ Sum[ Exp[-(sofk[[i,j,1,1]]^2 + sofk[[i,j,1,2]]^2 +
\t\tsofk[[i,j,1,3]]^2)/sigma^2 ] *
\t\t(1/(4 sofk[[i,2]] ( 1-sofk[[i,2]] ) )) *
\t\tsofk[[i,j,2]] * allecsfun[ sofk[[i,2]], sofk[[i,j,1,1]], 
\t\t\tsofk[[i,j,1,2]], sofk[[i,j,1,3]] ], 
\t{j,3,Length[sofk[[i]]] } ] ]}, 
{i,Length[sofk]} ];
TableForm[ straintable ]


TableForm[JCScoeffs]

\
\>", "Input",
  PageWidth->Infinity,
  ShowSpecialCharacters->False],

Cell[BoxData[
    \({{36.431044415452654`, 22.293385285690228`, 62.32568219646233`, 
        22.712589167626625`, 29.340408698920687`}, {38.130960837586706`, 
        24.661705177908047`, 67.1738379426763`, 25.086893205848863`, 
        32.20908954708225`}, {36.746149571758416`, 42.437254699066074`, 
        96.92864407171041`, 42.66957353631143`, 
        53.038919569497004`}, {32.732583602788026`, 51.09177294878555`, 
        107.28241662765419`, 51.27910564836841`, 
        62.68979112652033`}, {24.690299699095156`, 62.022226764779504`, 
        112.11117859479276`, 61.51978587445008`, 
        72.68363892377057`}, {16.7437754184905`, 65.43543416624816`, 
        84.35467430249899`, 60.789147823044416`, 
        65.41596795343389`}, {12.808009588620983`, 63.847199634841644`, 
        63.89606412032536`, 55.40967114619982`, 
        55.34217301075833`}, {6.528845682994614`, 43.43852902800484`, 
        32.31148856371435`, 33.89927455625667`, 
        30.554320149791398`}, {5.803312548256013`, 38.94509056191304`, 
        28.78365534666888`, 30.275575067527328`, 
        27.2029056008952`}}\)], "Output"],

Cell[BoxData[
    \({{92.21608117661452`, 56.43013150440339`, 157.76188305979528`, 
        57.49124133055489`, 74.26790951914299`}, {87.15648191448389`, 
        56.36961183521839`, 153.54020101183153`, 57.3414701847974`, 
        73.62077610761656`}, {48.994866095677885`, 56.58300626542143`, 
        129.23819209561387`, 56.89276471508191`, 
        70.718559425996`}, {36.82415655313653`, 57.47824456738374`, 
        120.69271870611095`, 57.688993854414456`, 
        70.52601501733537`}, {24.690299699095156`, 62.022226764779504`, 
        112.11117859479276`, 61.51978587445008`, 
        72.68363892377057`}, {18.83674734580181`, 73.61486343702917`, 
        94.89900859031137`, 68.38779130092497`, 
        73.59296394761313`}, {17.07734611816131`, 85.12959951312219`, 
        85.19475216043381`, 73.87956152826642`, 
        73.78956401434444`}, {14.923075846844831`, 99.28806634972534`, 
        73.85483100277565`, 77.48405612858667`, 
        69.83844605666604`}, {14.689634887773034`, 98.57976048484238`, 
        72.8586275962556`, 76.63504938967854`, 
        68.85735480226597`}}\)], "Output"],

Cell[BoxData[
    \({{"L10", 24.690299699095156`}, {"beta1", 
        32.732583602788026`}, {"beta2", 16.743775418490497`}, {"Z1", 
        36.746149571758416`}, {"Z2", 24.690299699095156`}, {"Z3", 
        12.808009588620981`}, {"L11", 112.11117859479276`}, {"alpha1", 
        107.28241662765417`}, {"alpha2", 84.35467430249899`}, {"V1", 
        96.92864407171041`}, {"V2", 112.11117859479276`}, {"V3", 
        63.896064120325356`}, {"gamma1", 51.09177294878555`}, {"gamma2", 
        65.43543416624814`}, {"Y1", 40.540219656630185`}, {"Y2", 
        62.022226764779504`}, {"Y3", 46.83413628610142`}, {"F1", 
        40.695098881460424`}, {"CH", 61.51978587445008`}, {"F3", 
        41.209117293673536`}, {"W1", 67.66882773690148`}, {"W2", 
        72.68363892377057`}, {"W3", 58.19347004728067`}, {"L1", 
        36.746149571758416`}, {"L3", 12.808009588620981`}, {"D1", 
        54.72689061192361`}, {"D7", 21.261784471977318`}, {"Ni8Nb_a", 
        29.362214850571437`}, {"Ni8Nb_b", 22.374201555084525`}, {"SQS14a", 
        42.68653624005056`}, {"SQS14b", 56.027031799584066`}, {"DO23a", 
        38.724354439411975`}, {"DO23b", 25.300333711454343`}, {"Z8", 
        6.528845682994614`}, {"Z8.2", 12.808009588620981`}, {"LPS-21a", 
        39.31202484814767`}, {"LPS-3a", 38.09188412702271`}, {"Z16", 
        3.2649634978056934`}, {"Z16.2", 6.528845579428467`}, {"D16", 
        18.587171110758998`}, {"Z3.r5xr5", 26.271209892231433`}, {"Z3.r2xr2", 
        14.348968218212343`}, {"P110_125a", 
        12.493481599057542`}, {"CXY_125a", 
        38.853690498636155`}, {"BMONO_3x1", 50.58403111134311`}, {"SMONOA", 
        43.43341774501796`}, {"P111_3x1", 61.55898713508738`}, {"P110_25", 
        58.704016114178295`}, {"CXY_25a", 76.8678125717264`}, {"CXY_25b", 
        60.6784907690293`}, {"BMONO_B", 79.29434907775568`}, {"SMONO_B", 
        81.67930374162407`}, {"TEST79", 58.56839980899813`}, {"Sc2S3", 
        79.39704538097953`}, {"D4", 112.11117859479276`}}\)], "Output"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"L10\"\>", "24.690299699070465`"},
          {"\<\"beta1\"\>", "32.73258360277348`"},
          {"\<\"beta2\"\>", "16.743775418483054`"},
          {"\<\"Z1\"\>", "36.74614957174004`"},
          {"\<\"Z2\"\>", "24.690299699088982`"},
          {"\<\"Z3\"\>", "12.808009588614578`"},
          {"\<\"L11\"\>", "112.11117859470869`"},
          {"\<\"alpha1\"\>", "107.28241662761842`"},
          {"\<\"alpha2\"\>", "84.35467430247088`"},
          {"\<\"V1\"\>", "96.92864407167406`"},
          {"\<\"V2\"\>", "112.11117859477174`"},
          {"\<\"V3\"\>", "63.896064120301396`"},
          {"\<\"gamma1\"\>", "51.091772948740136`"},
          {"\<\"gamma2\"\>", "65.43543416618998`"},
          {"\<\"Y1\"\>", "40.540219656603796`"},
          {"\<\"Y2\"\>", "62.02222676474849`"},
          {"\<\"Y3\"\>", "46.83413628607587`"},
          {"\<\"F1\"\>", "40.69509888141262`"},
          {"\<\"CH\"\>", "61.51978587437318`"},
          {"\<\"F3\"\>", "41.20911729362309`"},
          {"\<\"W1\"\>", "67.66882773685293`"},
          {"\<\"W2\"\>", "72.68363892372061`"},
          {"\<\"W3\"\>", "58.19347004723933`"},
          {"\<\"L1\"\>", "36.74614957172167`"},
          {"\<\"L3\"\>", "12.808009588608174`"},
          {"\<\"D1\"\>", "54.72689061187849`"},
          {"\<\"D7\"\>", "21.261784471960674`"},
          {"\<\"Ni8Nb_a\"\>", "29.362214850553432`"},
          {"\<\"Ni8Nb_b\"\>", "22.37420155506593`"},
          {"\<\"SQS14a\"\>", "42.686536240021795`"},
          {"\<\"SQS14b\"\>", "56.02703179954623`"},
          {"\<\"DO23a\"\>", "38.724354439371595`"},
          {"\<\"DO23b\"\>", "25.30033371142773`"},
          {"\<\"Z8\"\>", "6.528845682992049`"},
          {"\<\"Z8.2\"\>", "12.808009588618756`"},
          {"\<\"LPS-21a\"\>", "39.31202484810565`"},
          {"\<\"LPS-3a\"\>", "38.091884126983196`"},
          {"\<\"Z16\"\>", "3.2649634978045237`"},
          {"\<\"Z16.2\"\>", "6.528845579427493`"},
          {"\<\"D16\"\>", "18.587171110749377`"},
          {"\<\"Z3.r5xr5\"\>", "26.2712098922161`"},
          {"\<\"Z3.r2xr2\"\>", "14.348968218196973`"},
          {"\<\"P110_125a\"\>", "12.493481599048572`"},
          {"\<\"CXY_125a\"\>", "38.85369049860384`"},
          {"\<\"BMONO_3x1\"\>", "50.584031111314225`"},
          {"\<\"SMONOA\"\>", "43.43341774498031`"},
          {"\<\"P111_3x1\"\>", "61.558987135054245`"},
          {"\<\"P110_25\"\>", "58.70401611414393`"},
          {"\<\"CXY_25a\"\>", "76.8678125716657`"},
          {"\<\"CXY_25b\"\>", "60.67849076898022`"},
          {"\<\"BMONO_B\"\>", "79.2943490777026`"},
          {"\<\"SMONO_B\"\>", "81.67930374155763`"},
          {"\<\"TEST79\"\>", "58.56839980894225`"},
          {"\<\"Sc2S3\"\>", "79.3970453809145`"},
          {"\<\"D4\"\>", "112.11117859470869`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"0.025`", GridBox[{
                {"347.34358631237365`"},
                {\(-51.62834917007435`\)},
                {"109.90117368207565`"},
                {"31.97630214131236`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.05`", GridBox[{
                {"330.15308788066943`"},
                {\(-49.56137406740188`\)},
                {"96.83163505675283`"},
                {"26.198567535386612`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.07500000000000001`", GridBox[{
                {"316.45446608147137`"},
                {\(-48.994756899390374`\)},
                {"86.47615418140303`"},
                {"21.279721627085348`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.1`", GridBox[{
                {"305.2372782357112`"},
                {\(-49.34224005124682`\)},
                {"77.93306982765675`"},
                {"16.91623990864567`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.125`", GridBox[{
                {"295.8762164042852`"},
                {\(-50.327351867069474`\)},
                {"70.68418592185951`"},
                {"12.934497756283557`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.15000000000000002`", GridBox[{
                {"287.9508422812593`"},
                {\(-51.82862997156854`\)},
                {"64.38664878814521`"},
                {"9.20543213079101`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.17500000000000002`", GridBox[{
                {"281.0183165530017`"},
                {\(-54.275472007850354`\)},
                {"58.63891615711975`"},
                {"5.364815938710991`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.2`", GridBox[{
                {"274.99717001511635`"},
                {\(-57.20161330878668`\)},
                {"53.414203653188174`"},
                {"1.5824556111456902`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.225`", GridBox[{
                {"270.15166415502927`"},
                {\(-59.195208170290826`\)},
                {"49.05012245593495`"},
                {\(-1.425216162839056`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.25`", GridBox[{
                {"266.2555184204762`"},
                {\(-60.59558652761812`\)},
                {"45.33240557655773`"},
                {\(-3.890665348324788`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.275`", GridBox[{
                {"263.15008254011474`"},
                {\(-61.613578983835446`\)},
                {"42.11234746311428`"},
                {\(-5.963944577265831`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.30000000000000004`", GridBox[{
                {"260.7204519069454`"},
                {\(-62.38423989934692`\)},
                {"39.282542411662035`"},
                {\(-7.745017133636924`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.325`", GridBox[{
                {"258.88082413935666`"},
                {\(-62.996819999013745`\)},
                {"36.7622424201486`"},
                {\(-9.302404431533077`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.35000000000000003`", GridBox[{
                {"257.56517973230774`"},
                {\(-63.51179430680707`\)},
                {"34.48824748462744`"},
                {\(-10.683993635688356`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.375`", GridBox[{
                {"256.720886694799`"},
                {\(-63.97074806505791`\)},
                {"32.40885433603823`"},
                {\(-11.9234663294883`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.4`", GridBox[{
                {"256.30379909224126`"},
                {\(-64.4020912994279`\)},
                {"30.479443023650564`"},
                {\(-13.044173714701566`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.42500000000000004`", GridBox[{
                {"256.27382792546854`"},
                {\(-64.82402734741018`\)},
                {"28.65875651900591`"},
                {\(-14.061438807198918`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.45`", GridBox[{
                {"256.58994463880805`"},
                {\(-65.24517338596745`\)},
                {"26.904992698231442`"},
                {\(-14.983845053433608`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.47500000000000003`", GridBox[{
                {"257.20293931021155`"},
                {\(-65.66199947326994`\)},
                {"25.17033120538287`"},
                {\(-15.813932803405365`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.5`", GridBox[{
                {"258.04173662019787`"},
                {\(-66.04906248731167`\)},
                {"23.390332893761872`"},
                {\(-16.549047102438497`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.525`", GridBox[{
                {"258.9762750749157`"},
                {\(-66.32282348324094`\)},
                {"21.453286134422335`"},
                {\(-17.18548646748689`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.55`", GridBox[{
                {"259.6048721277542`"},
                {\(-66.10360599001496`\)},
                {"19.015774754487484`"},
                {\(-17.75391491119556`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.5750000000000001`", GridBox[{
                {"259.40222350922016`"},
                {\(-64.87917549533834`\)},
                {"15.627499324416755`"},
                {\(-18.296695717414533`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.6000000000000001`", GridBox[{
                {"259.03284926208016`"},
                {\(-63.471708440560164`\)},
                {"11.858355512653256`"},
                {\(-18.65529080096729`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.625`", GridBox[{
                {"258.7434340783285`"},
                {\(-62.149249590334534`\)},
                {"7.866915133547992`"},
                {\(-18.78313676207396`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.65`", GridBox[{
                {"258.68916190051567`"},
                {\(-60.98024119575454`\)},
                {"3.6732655427194056`"},
                {\(-18.697807120665573`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.675`", GridBox[{
                {"259.0280407008282`"},
                {\(-59.98328402694557`\)},
                {\(-0.7401422774085435`\)},
                {\(-18.43933388125706`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.7000000000000001`", GridBox[{
                {"259.9167593187258`"},
                {\(-59.16419869526499`\)},
                {\(-5.414369474011851`\)},
                {\(-18.04563909300452`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.7250000000000001`", GridBox[{
                {"261.5114396035798`"},
                {\(-58.52932190175759`\)},
                {\(-10.411114375230689`\)},
                {\(-17.54364982104381`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.75`", GridBox[{
                {"263.9725029129884`"},
                {\(-58.09052900218737`\)},
                {\(-15.811476856421521`\)},
                {\(-16.947799072946395`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.775`", GridBox[{
                {"267.45689347346456`"},
                {\(-57.86799039774465`\)},
                {\(-21.709723829481476`\)},
                {\(-16.25851980874607`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.8`", GridBox[{
                {"272.03801210478656`"},
                {\(-57.89374228495792`\)},
                {\(-28.174355292512164`\)},
                {\(-15.451384354633648`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.8250000000000001`", GridBox[{
                {"273.5932634334437`"},
                {\(-59.033358728563904`\)},
                {\(-33.97514072911789`\)},
                {\(-13.131944221948299`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.8500000000000001`", GridBox[{
                {"268.8419374107121`"},
                {\(-58.73342042485633`\)},
                {\(-35.21880427632883`\)},
                {\(-11.790824749976117`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.875`", GridBox[{
                {"263.42233721565873`"},
                {\(-57.95051876774161`\)},
                {\(-35.5306548539482`\)},
                {\(-10.95938016349641`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.9`", GridBox[{
                {"257.93845595036515`"},
                {\(-57.05993669499947`\)},
                {\(-35.55224189374526`\)},
                {\(-10.283435223741003`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.925`", GridBox[{
                {"252.51454286378063`"},
                {\(-56.12353259617297`\)},
                {\(-35.40856402109058`\)},
                {\(-9.706042750484688`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.9500000000000001`", GridBox[{
                {"247.20562504341024`"},
                {\(-55.1697104990046`\)},
                {\(-35.16046194064921`\)},
                {\(-9.199917340842035`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0.9750000000000001`", GridBox[{
                {"242.038598745328`"},
                {\(-54.21407459814312`\)},
                {\(-34.843186223022975`\)},
                {\(-8.748912481435699`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{0.025000000000000001, {
        347.34358631237365, -51.628349170074351, 109.90117368207565, 
        31.97630214131236}}, {0.050000000000000003, {
        330.15308788066943, -49.561374067401879, 96.83163505675283, 
        26.198567535386612}}, {0.075000000000000011, {
        316.45446608147137, -48.994756899390374, 86.476154181403032, 
        21.279721627085348}}, {0.10000000000000001, {
        305.23727823571119, -49.342240051246819, 77.933069827656752, 
        16.916239908645672}}, {0.125, {
        295.87621640428517, -50.327351867069474, 70.684185921859509, 
        12.934497756283557}}, {0.15000000000000002, {
        287.95084228125933, -51.828629971568539, 64.386648788145209, 
        9.2054321307910101}}, {0.17500000000000002, {
        281.01831655300168, -54.275472007850354, 58.638916157119752, 
        5.3648159387109908}}, {0.20000000000000001, {
        274.99717001511635, -57.201613308786683, 53.414203653188174, 
        1.5824556111456902}}, {0.22500000000000001, {
        270.15166415502927, -59.195208170290826, 
        49.050122455934947, -1.4252161628390561}}, {0.25, {
        266.25551842047622, -60.595586527618117, 
        45.332405576557733, -3.8906653483247879}}, {0.27500000000000002, {
        263.15008254011474, -61.613578983835446, 
        42.112347463114283, -5.9639445772658313}}, {0.30000000000000004, {
        260.72045190694541, -62.384239899346923, 
        39.282542411662035, -7.7450171336369236}}, {0.32500000000000001, {
        258.88082413935666, -62.996819999013745, 
        36.762242420148603, -9.3024044315330769}}, {0.35000000000000003, {
        257.56517973230774, -63.511794306807069, 
        34.488247484627443, -10.683993635688356}}, {0.375, {
        256.72088669479899, -63.970748065057911, 
        32.408854336038232, -11.923466329488299}}, {0.40000000000000002, {
        256.30379909224126, -64.402091299427894, 
        30.479443023650564, -13.044173714701566}}, {0.42500000000000004, {
        256.27382792546854, -64.82402734741018, 
        28.658756519005909, -14.061438807198918}}, {0.45000000000000001, {
        256.58994463880805, -65.245173385967448, 
        26.904992698231442, -14.983845053433608}}, {0.47500000000000003, {
        257.20293931021155, -65.661999473269944, 
        25.170331205382869, -15.813932803405365}}, {0.5, {
        258.04173662019787, -66.049062487311673, 
        23.390332893761872, -16.549047102438497}}, {0.52500000000000002, {
        258.97627507491569, -66.322823483240938, 
        21.453286134422335, -17.185486467486889}}, {0.55000000000000004, {
        259.60487212775422, -66.103605990014955, 
        19.015774754487484, -17.753914911195562}}, {0.57500000000000007, {
        259.40222350922016, -64.879175495338345, 
        15.627499324416755, -18.296695717414533}}, {0.60000000000000009, {
        259.03284926208016, -63.471708440560164, 
        11.858355512653256, -18.65529080096729}}, {0.625, {
        258.74343407832851, -62.149249590334534, 
        7.8669151335479919, -18.783136762073958}}, {0.65000000000000002, {
        258.68916190051567, -60.980241195754537, 
        3.6732655427194056, -18.697807120665573}}, {0.67500000000000004, {
        259.02804070082823, -59.983284026945569, -0.74014227740854355, \
-18.43933388125706}}, {0.70000000000000007, {
        259.91675931872578, -59.164198695264993, -5.4143694740118509, \
-18.045639093004521}}, {0.72500000000000009, {
        261.51143960357979, -58.529321901757591, -10.411114375230689, \
-17.543649821043811}}, {0.75, {
        263.97250291298838, -58.090529002187367, -15.811476856421521, \
-16.947799072946395}}, {0.77500000000000002, {
        267.45689347346456, -57.867990397744649, -21.709723829481476, \
-16.258519808746069}}, {0.80000000000000004, {
        272.03801210478656, -57.893742284957924, -28.174355292512164, \
-15.451384354633648}}, {0.82500000000000007, {
        273.59326343344372, -59.033358728563904, -33.975140729117889, \
-13.131944221948299}}, {0.85000000000000009, {
        268.84193741071209, -58.733420424856327, -35.218804276328832, \
-11.790824749976117}}, {0.875, {
        263.42233721565873, -57.950518767741613, -35.530654853948199, \
-10.959380163496411}}, {0.90000000000000002, {
        257.93845595036515, -57.059936694999472, -35.552241893745261, \
-10.283435223741003}}, {0.92500000000000004, {
        252.51454286378063, -56.123532596172971, -35.408564021090577, \
-9.7060427504846878}}, {0.95000000000000007, {
        247.20562504341024, -55.169710499004601, -35.160461940649213, \
-9.1999173408420347}}, {0.97500000000000009, {
        242.03859874532799, -54.214074598143121, -34.843186223022975, \
-8.7489124814356991}}}]]], "Output"]
}, Open  ]]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowSize->{1024, 720},
WindowMargins->{{-1, Automatic}, {-18, Automatic}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PrintingMargins"->{{72, 72}, {54, 54}},
"PaperSize"->{612, 1440},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->True,
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "homes", "s", \
"ss", "sst", "sstu-6"}, "strain_lab.nb.ps", CharacterEncoding -> \
"iso8859-1"],
"Magnification"->1}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 330, 8, 87, "Input"],
Cell[2087, 61, 267, 10, 117, "Input"],

Cell[CellGroupData[{
Cell[2379, 75, 1657, 33, 567, "Input"],
Cell[4039, 110, 130, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4206, 118, 6096, 92, 2112, "Input"],
Cell[10305, 212, 135, 3, 27, "Output"],
Cell[10443, 217, 135, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10615, 225, 1298, 22, 267, "Input"],
Cell[11916, 249, 135, 3, 27, "Output"]
}, Open  ]],
Cell[12066, 255, 3254, 79, 792, "Input"],

Cell[CellGroupData[{
Cell[15345, 338, 707, 15, 87, "Input"],
Cell[16055, 355, 135, 3, 27, "Output"],
Cell[16193, 360, 135, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16365, 368, 1399, 27, 222, "Input"],
Cell[17767, 397, 135, 3, 27, "Output"],
Cell[17905, 402, 135, 3, 27, "Output"],
Cell[18043, 407, 130, 3, 27, "Output"]
}, Open  ]],
Cell[18188, 413, 1416, 23, 447, "Input"],

Cell[CellGroupData[{
Cell[19629, 440, 919, 24, 252, "Input"],
Cell[20551, 466, 133, 3, 23, "Print"],
Cell[20687, 471, 133, 3, 23, "Print"],
Cell[20823, 476, 133, 3, 23, "Print"],
Cell[20959, 481, 133, 3, 23, "Print"],
Cell[21095, 486, 133, 3, 23, "Print"],
Cell[21231, 491, 133, 3, 23, "Print"],
Cell[21367, 496, 133, 3, 23, "Print"],
Cell[21503, 501, 133, 3, 23, "Print"],
Cell[21639, 506, 135, 3, 23, "Print"],
Cell[21777, 511, 135, 3, 23, "Print"],
Cell[21915, 516, 135, 3, 23, "Print"],
Cell[22053, 521, 135, 3, 23, "Print"],
Cell[22191, 526, 135, 3, 23, "Print"],
Cell[22329, 531, 135, 3, 23, "Print"],
Cell[22467, 536, 135, 3, 23, "Print"],
Cell[22605, 541, 135, 3, 23, "Print"],
Cell[22743, 546, 135, 3, 23, "Print"],
Cell[22881, 551, 135, 3, 23, "Print"],
Cell[23019, 556, 135, 3, 23, "Print"],
Cell[23157, 561, 135, 3, 23, "Print"],
Cell[23295, 566, 135, 3, 23, "Print"],
Cell[23433, 571, 135, 3, 23, "Print"],
Cell[23571, 576, 135, 3, 23, "Print"],
Cell[23709, 581, 135, 3, 23, "Print"],
Cell[23847, 586, 135, 3, 23, "Print"],
Cell[23985, 591, 135, 3, 23, "Print"],
Cell[24123, 596, 135, 3, 23, "Print"],
Cell[24261, 601, 135, 3, 23, "Print"],
Cell[24399, 606, 135, 3, 23, "Print"],
Cell[24537, 611, 135, 3, 23, "Print"],
Cell[24675, 616, 135, 3, 23, "Print"],
Cell[24813, 621, 135, 3, 23, "Print"],
Cell[24951, 626, 135, 3, 23, "Print"],
Cell[25089, 631, 135, 3, 23, "Print"],
Cell[25227, 636, 135, 3, 23, "Print"],
Cell[25365, 641, 135, 3, 23, "Print"],
Cell[25503, 646, 135, 3, 23, "Print"],
Cell[25641, 651, 135, 3, 23, "Print"],
Cell[25779, 656, 135, 3, 23, "Print"]
}, Open  ]],
Cell[25929, 662, 286, 9, 102, "Input"],
Cell[26218, 673, 920, 16, 282, "Input"],

Cell[CellGroupData[{
Cell[27163, 693, 1581, 27, 282, "Input"],
Cell[28747, 722, 135, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28919, 730, 320, 11, 132, "Input"],
Cell[29242, 743, 130, 3, 27, "Output"],
Cell[29375, 748, 135, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29547, 756, 1266, 21, 162, "Input"],
Cell[30816, 779, 135, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30988, 787, 1252, 24, 171, "Input"],
Cell[32243, 813, 135, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32415, 821, 5301, 126, 1797, "Input"],
Cell[37719, 949, 1122, 18, 91, "Output"],
Cell[38844, 969, 1112, 18, 91, "Output"],
Cell[39959, 989, 1993, 29, 139, "Output"],
Cell[41955, 1020, 3037, 63, 999, "Output"],
Cell[44995, 1085, 19268, 475, 2349, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

